@@ -127,7 +127,7 @@ ApiCacheTypeDef = TypedDict(
 )
 
 ApiKeyTypeDef = TypedDict(
-    "ApiKeyTypeDef", {"id": str, "description": str, "expires": int}, total=False
+    "ApiKeyTypeDef", {"id": str, "description": str, "expires": int, "deletes": int}, total=False
 )
 
 _RequiredAuthorizationConfigTypeDef = TypedDict(
@@ -247,6 +247,7 @@ GraphqlApiTypeDef = TypedDict(
         "tags": Dict[str, str],
         "additionalAuthenticationProviders": List["AdditionalAuthenticationProviderTypeDef"],
         "xrayEnabled": bool,
+        "wafWebAclArn": str,
     },
     total=False,
 )
